# Factorio circuit AST

This package contains a kind of Abstract Syntax Tree used for the interpreter. This can be built from the IR or a
blueprint string. It enables interpreting and debugging circuits.
